@@ -178,6 +178,27 @@ class LabeledEnum(str, Enum):
         return hash(self._value_)
 
 
+# Add _repr_html_ after class definition to avoid Enum member name restrictions
+def _labeled_enum_repr_html(self) -> str:
+    """Return HTML representation for Jupyter notebook display.
+
+    This method is automatically called by Jupyter when displaying the object
+    as a cell output, providing a styled representation of the enum value.
+
+    Returns:
+        HTML representation of the enum value with styling.
+    """
+    enum_class = self.__class__.__name__
+    return (
+        f'<span style="color: #5294e2; font-family: monospace;">'
+        f"{enum_class}.<b>{self.name}</b></span> "
+        f'(<code>{self._value_!r}</code>: "{self.label}")'
+    )
+
+
+LabeledEnum._repr_html_ = _labeled_enum_repr_html
+
+
 class NumericTypeItem(DataItem):
     """Numeric data item
 
@@ -1221,9 +1242,9 @@ class MultipleChoiceItem(ChoiceItem):
         """Override DataItem method"""
         if not self.get_prop("data", "check_value", True):
             return True
-        if not isinstance(value, tuple):
+        if not isinstance(value, (tuple, list)):
             if raise_exception:
-                raise ValueError(f"Invalid value '{value}' (expecting tuple)")
+                raise ValueError(f"Invalid value '{value}' (expecting tuple or list)")
             return False
         for val in value:
             if val not in [v for v, _k, _i in self.get_prop("data", "choices", [])]:
